# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.db import models
from django.utils.translation import ugettext_lazy as _
from django_models_ext import BaseModelMixin


class OnerrorReportInfo(BaseModelMixin):
    lineNo = models.IntegerField(_(u'lineNo'), default=0, help_text=u'异常行号')
    columnNo = models.IntegerField(_(u'columnNo'), default=0, help_text=u'异常列号')
    scriptURI = models.CharField(_(u'scriptURI'), max_length=255, blank=True, null=True, help_text=u'异常文件路径')
    errorMessage = models.CharField(_(u'errorMessage'), max_length=255, blank=True, null=True, help_text=u'异常信息')
    stack = models.TextField(_(u'stack'), blank=True, null=True, help_text=u'异常堆栈信息')

    class Meta:
        verbose_name = _(u'onerrorreportinfo')
        verbose_name_plural = _(u'onerrorreportinfo')

    def __unicode__(self):
        return unicode(self.pk)



# -*- coding: utf-8 -*-
# Generated by Django 1.11.13 on 2018-07-23 06:14
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='OnerrorReportInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.BooleanField(db_index=True, default=True, help_text='Status', verbose_name='status')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Create Time', verbose_name='created_at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Update Time', verbose_name='updated_at')),
                ('lineNo', models.IntegerField(default=0, help_text='\u5f02\u5e38\u884c\u53f7', verbose_name='lineNo')),
                ('columnNo', models.IntegerField(default=0, help_text='\u5f02\u5e38\u5217\u53f7', verbose_name='columnNo')),
                ('scriptURI', models.CharField(blank=True, help_text='\u5f02\u5e38\u6587\u4ef6\u8def\u5f84', max_length=255, null=True, verbose_name='scriptURI')),
                ('errorMessage', models.CharField(blank=True, help_text='\u5f02\u5e38\u4fe1\u606f', max_length=255, null=True, verbose_name='errorMessage')),
                ('stack', models.TextField(blank=True, help_text='\u5f02\u5e38\u5806\u6808\u4fe1\u606f', null=True, verbose_name='stack')),
            ],
            options={
                'verbose_name': 'onerrorreportinfo',
                'verbose_name_plural': 'onerrorreportinfo',
            },
        ),
    ]



import json

from django_onerror.models import OnerrorReportInfo
from django_response import response


def err_report(request):
    payload = json.loads(request.body)

    OnerrorReportInfo.objects.create(
        lineNo=payload.get('lineNo', -1),
        columnNo=payload.get('columnNo', -1),
        scriptURI=payload.get('scriptURI', ''),
        errorMessage=payload.get('errorMessage', ''),
        stack=payload.get('stack', ''),
    )

    return response()



# -*- coding: utf-8 -*-

from django.contrib import admin
from django_admin import DeleteOnlyModelAdmin
from django_onerror.models import OnerrorReportInfo


class OnerrorReportInfoAdmin(DeleteOnlyModelAdmin, admin.ModelAdmin):
    list_display = ('lineNo', 'columnNo', 'scriptURI', 'errorMessage', 'stack', 'created_at', 'updated_at')
    search_fields = ('lineNo', 'columnNo', 'scriptURI', 'errorMessage', 'stack')


admin.site.register(OnerrorReportInfo, OnerrorReportInfoAdmin)
